Documentation
¶
Overview ¶
Package authen code generated by lark suite oapi sdk gen
Package authen code generated by lark suite oapi sdk gen
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AuthenAccessTokenReq ¶
type AuthenAccessTokenReq struct {
Body *AuthenAccessTokenReqBody `body:""`
}
type AuthenAccessTokenResp ¶
type AuthenAccessTokenResp struct {
*lark.RawResponse `json:"-"`
lark.CodeError
Data *UserAccessTokenInfo `json:"data"`
}
type AuthenRefreshAccessTokenReq ¶
type AuthenRefreshAccessTokenReq struct {
Body *AuthenRefreshAccessTokenReqBody `body:""`
}
type AuthenRefreshAccessTokenResp ¶
type AuthenRefreshAccessTokenResp struct {
*lark.RawResponse `json:"-"`
lark.CodeError
Data *UserAccessTokenInfo `json:"data"`
}
type AuthenService ¶
type AuthenService struct {
Authen *authen
}
func New ¶
func New(app *lark.App) *AuthenService
type AuthenUserInfoResp ¶
type AuthenUserInfoResp struct {
*lark.RawResponse `json:"-"`
lark.CodeError
Data *UserInfo `json:"data"`
}
type UserAccessTokenInfo ¶
type UserAccessTokenInfo struct {
AccessToken *string `json:"access_token,omitempty"`
TokenType *string `json:"token_type,omitempty"`
ExpiresIn *int `json:"expires_in,omitempty"`
Name *string `json:"name,omitempty"`
EnName *string `json:"en_name,omitempty"`
AvatarUrl *string `json:"avatar_url,omitempty"`
AvatarThumb *string `json:"avatar_thumb,omitempty"`
AvatarMiddle *string `json:"avatar_middle,omitempty"`
AvatarBig *string `json:"avatar_big,omitempty"`
OpenId *string `json:"open_id,omitempty"`
UnionId *string `json:"union_id,omitempty"`
Email *string `json:"email,omitempty"`
UserId *string `json:"user_id,omitempty"`
Mobile *string `json:"mobile,omitempty"`
TenantKey *string `json:"tenant_key,omitempty"`
RefreshExpiresIn *int `json:"refresh_expires_in,omitempty"`
RefreshToken *string `json:"refresh_token,omitempty"`
}
type UserInfo ¶
type UserInfo struct {
Name *string `json:"name,omitempty"`
EnName *string `json:"en_name,omitempty"`
AvatarUrl *string `json:"avatar_url,omitempty"`
AvatarThumb *string `json:"avatar_thumb,omitempty"`
AvatarMiddle *string `json:"avatar_middle,omitempty"`
AvatarBig *string `json:"avatar_big,omitempty"`
OpenId *string `json:"open_id,omitempty"`
UnionId *string `json:"union_id,omitempty"`
Email *string `json:"email,omitempty"`
UserId *string `json:"user_id,omitempty"`
Mobile *string `json:"mobile,omitempty"`
TenantKey *string `json:"tenant_key,omitempty"`
}
Click to show internal directories.
Click to hide internal directories.